#!/usr/bin/env python

"""
Utility to build Assembly/C/C++ projects
"""

from .app import app_run

if __name__ == '__main__':
	app_run()
